from typing import Optional, List

from vkbottle_types.responses import base, storage
from .base_category import BaseCategory


class StorageCategory(BaseCategory):
    async def get(
        self,
        key: Optional[str] = None,
        keys: Optional[List[str]] = None,
        user_id: Optional[int] = None,
        **kwargs
    ) -> storage.GetV5110ResponseModel:
        """Returns a value of variable with the name set by key parameter.
        :param key:
        :param keys:
        :param user_id:
        """

        params = self.get_set_params(locals())
        return storage.GetV5110Response(**await self.api.request("storage.get", params))

    async def get_keys(
        self,
        user_id: Optional[int] = None,
        offset: Optional[int] = None,
        count: Optional[int] = None,
        **kwargs
    ) -> storage.GetKeysResponseModel:
        """Returns the names of all variables.
        :param user_id: user id, whose variables names are returned if they were requested with a server method.
        :param offset:
        :param count: amount of variable names the info needs to be collected from.
        """

        params = self.get_set_params(locals())
        return storage.GetKeysResponse(
            **await self.api.request("storage.getKeys", params)
        )

    async def set(
        self,
        key: str,
        value: Optional[str] = None,
        user_id: Optional[int] = None,
        **kwargs
    ) -> base.OkResponseModel:
        """Saves a value of variable with the name set by 'key' parameter.
        :param key:
        :param value:
        :param user_id:
        """

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("storage.set", params))



from typing import Optional

from .base_response import BaseResponse


class GetServerUrlResponse(BaseResponse):
    response: Optional["GetServerUrlResponseModel"] = None


class GetServerUrlResponseModel(BaseResponse):
    endpoint: Optional[str] = None
    key: Optional[str] = None


GetServerUrlResponse.update_forward_refs()



from typing import Optional, List

from vkbottle_types.objects import WidgetsWidgetPage, WidgetsWidgetComment
from .base_response import BaseResponse


class GetCommentsResponse(BaseResponse):
    response: Optional["GetCommentsResponseModel"] = None


class GetPagesResponse(BaseResponse):
    response: Optional["GetPagesResponseModel"] = None


class GetCommentsResponseModel(BaseResponse):
    count: Optional[int] = None
    posts: Optional[List["WidgetsWidgetComment"]] = None


class GetPagesResponseModel(BaseResponse):
    count: Optional[int] = None
    pages: Optional[List["WidgetsWidgetPage"]] = None


GetCommentsResponse.update_forward_refs()
GetPagesResponse.update_forward_refs()



import typing
from typing import Optional, List

from vkbottle_types.responses import polls, base
from .base_category import BaseCategory

if typing.TYPE_CHECKING:
    from vkbottle_types.objects import users as objects_users


class PollsCategory(BaseCategory):
    async def add_vote(
        self,
        poll_id: int,
        answer_ids: List[int],
        owner_id: Optional[int] = None,
        is_board: Optional[bool] = None,
        **kwargs
    ) -> polls.AddVoteResponseModel:
        """Adds the current user's vote to the selected answer in the poll.
        :param poll_id: Poll ID.
        :param answer_ids:
        :param owner_id: ID of the user or community that owns the poll. Use a negative value to designate a community ID.
        :param is_board:
        """

        params = self.get_set_params(locals())
        return polls.AddVoteResponse(**await self.api.request("polls.addVote", params))

    async def create(
        self,
        question: Optional[str] = None,
        is_anonymous: Optional[bool] = None,
        is_multiple: Optional[bool] = None,
        end_date: Optional[int] = None,
        owner_id: Optional[int] = None,
        add_answers: Optional[str] = None,
        photo_id: Optional[int] = None,
        background_id: Optional[str] = None,
        disable_unvote: Optional[bool] = None,
        **kwargs
    ) -> polls.CreateResponseModel:
        """Creates polls that can be attached to the users' or communities' posts.
        :param question: question text
        :param is_anonymous: '1' – anonymous poll, participants list is hidden,, '0' – public poll, participants list is available,, Default value is '0'.
        :param is_multiple:
        :param end_date:
        :param owner_id: If a poll will be added to a communty it is required to send a negative group identifier. Current user by default.
        :param add_answers: available answers list, for example: " ["yes","no","maybe"]", There can be from 1 to 10 answers.
        :param photo_id:
        :param background_id:
        :param disable_unvote:
        """

        params = self.get_set_params(locals())
        return polls.CreateResponse(**await self.api.request("polls.create", params))

    async def delete_vote(
        self,
        poll_id: int,
        answer_id: int,
        owner_id: Optional[int] = None,
        is_board: Optional[bool] = None,
        **kwargs
    ) -> polls.DeleteVoteResponseModel:
        """Deletes the current user's vote from the selected answer in the poll.
        :param poll_id: Poll ID.
        :param answer_id: Answer ID.
        :param owner_id: ID of the user or community that owns the poll. Use a negative value to designate a community ID.
        :param is_board:
        """

        params = self.get_set_params(locals())
        return polls.DeleteVoteResponse(
            **await self.api.request("polls.deleteVote", params)
        )

    async def edit(
        self,
        poll_id: int,
        owner_id: Optional[int] = None,
        question: Optional[str] = None,
        add_answers: Optional[str] = None,
        edit_answers: Optional[str] = None,
        delete_answers: Optional[str] = None,
        end_date: Optional[int] = None,
        photo_id: Optional[int] = None,
        background_id: Optional[str] = None,
        **kwargs
    ) -> base.OkResponseModel:
        """Edits created polls
        :param poll_id: edited poll's id
        :param owner_id: poll owner id
        :param question: new question text
        :param add_answers: answers list, for example: , "["yes","no","maybe"]"
        :param edit_answers: object containing answers that need to be edited,, key – answer id, value – new answer text. Example: {"382967099":"option1", "382967103":"option2"}"
        :param delete_answers: list of answer ids to be deleted. For example: "[382967099, 382967103]"
        :param end_date:
        :param photo_id:
        :param background_id:
        """

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("polls.edit", params))

    async def get_by_id(
        self,
        poll_id: int,
        owner_id: Optional[int] = None,
        is_board: Optional[bool] = None,
        extended: Optional[bool] = None,
        friends_count: Optional[int] = None,
        fields: Optional[List[str]] = None,
        name_case: Optional[str] = None,
        **kwargs
    ) -> polls.GetByIdResponseModel:
        """Returns detailed information about a poll by its ID.
        :param poll_id: Poll ID.
        :param owner_id: ID of the user or community that owns the poll. Use a negative value to designate a community ID.
        :param is_board: '1' – poll is in a board, '0' – poll is on a wall. '0' by default.
        :param extended:
        :param friends_count:
        :param fields:
        :param name_case:
        """

        params = self.get_set_params(locals())
        return polls.GetByIdResponse(**await self.api.request("polls.getById", params))

    async def get_voters(
        self,
        poll_id: int,
        answer_ids: List[int],
        owner_id: Optional[int] = None,
        is_board: Optional[bool] = None,
        friends_only: Optional[bool] = None,
        offset: Optional[int] = None,
        count: Optional[int] = None,
        fields: Optional[List["objects_users.Fields"]] = None,
        name_case: Optional[str] = None,
        **kwargs
    ) -> polls.GetVotersResponseModel:
        """Returns a list of IDs of users who selected specific answers in the poll.
        :param poll_id: Poll ID.
        :param answer_ids: Answer IDs.
        :param owner_id: ID of the user or community that owns the poll. Use a negative value to designate a community ID.
        :param is_board:
        :param friends_only: '1' — to return only current user's friends, '0' — to return all users (default),
        :param offset: Offset needed to return a specific subset of voters. '0' — (default)
        :param count: Number of user IDs to return (if the 'friends_only' parameter is not set, maximum '1000', otherwise '10'). '100' — (default)
        :param fields: Profile fields to return. Sample values: 'nickname', 'screen_name', 'sex', 'bdate (birthdate)', 'city', 'country', 'timezone', 'photo', 'photo_medium', 'photo_big', 'has_mobile', 'rate', 'contacts', 'education', 'online', 'counters'.
        :param name_case: Case for declension of user name and surname: , 'nom' — nominative (default, **kwargs) , 'gen' — genitive , 'dat' — dative , 'acc' — accusative , 'ins' — instrumental , 'abl' — prepositional
        """

        params = self.get_set_params(locals())
        return polls.GetVotersResponse(
            **await self.api.request("polls.getVoters", params)
        )



from abc import ABC, abstractmethod
from vkbottle_types.methods import (
    account,
    ads,
    apps,
    appWidgets,
    auth,
    board,
    database,
    docs,
    downloadedGames,
    fave,
    friends,
    gifts,
    groups,
    leads,
    likes,
    market,
    messages,
    newsfeed,
    notes,
    notifications,
    orders,
    pages,
    photos,
    polls,
    prettyCards,
    search,
    secure,
    stats,
    status,
    storage,
    stories,
    streaming,
    users,
    utils,
    video,
    wall,
)
import typing

if typing.TYPE_CHECKING:
    from vkbottle import API


class APICategories(ABC):
    @property
    def account(self) -> account.AccountCategory:
        return account.AccountCategory(self.api_instance)

    @property
    def ads(self) -> ads.AdsCategory:
        return ads.AdsCategory(self.api_instance)

    @property
    def apps(self) -> apps.AppsCategory:
        return apps.AppsCategory(self.api_instance)

    @property
    def app_widgets(self) -> appWidgets.AppWidgetsCategory:
        return appWidgets.AppWidgetsCategory(self.api_instance)

    @property
    def auth(self) -> auth.AuthCategory:
        return auth.AuthCategory(self.api_instance)

    @property
    def board(self) -> board.BoardCategory:
        return board.BoardCategory(self.api_instance)

    @property
    def database(self) -> database.DatabaseCategory:
        return database.DatabaseCategory(self.api_instance)

    @property
    def docs(self) -> docs.DocsCategory:
        return docs.DocsCategory(self.api_instance)

    @property
    def downloaded_games(self) -> downloadedGames.DownloadedGamesCategory:
        return downloadedGames.DownloadedGamesCategory(self.api_instance)

    @property
    def fave(self) -> fave.FaveCategory:
        return fave.FaveCategory(self.api_instance)

    @property
    def friends(self) -> friends.FriendsCategory:
        return friends.FriendsCategory(self.api_instance)

    @property
    def gifts(self) -> gifts.GiftsCategory:
        return gifts.GiftsCategory(self.api_instance)

    @property
    def groups(self) -> groups.GroupsCategory:
        return groups.GroupsCategory(self.api_instance)

    @property
    def leads(self) -> leads.LeadsCategory:
        return leads.LeadsCategory(self.api_instance)

    @property
    def likes(self) -> likes.LikesCategory:
        return likes.LikesCategory(self.api_instance)

    @property
    def market(self) -> market.MarketCategory:
        return market.MarketCategory(self.api_instance)

    @property
    def messages(self) -> messages.MessagesCategory:
        return messages.MessagesCategory(self.api_instance)

    @property
    def newsfeed(self) -> newsfeed.NewsfeedCategory:
        return newsfeed.NewsfeedCategory(self.api_instance)

    @property
    def notes(self) -> notes.NotesCategory:
        return notes.NotesCategory(self.api_instance)

    @property
    def notifications(self) -> notifications.NotificationsCategory:
        return notifications.NotificationsCategory(self.api_instance)

    @property
    def orders(self) -> orders.OrdersCategory:
        return orders.OrdersCategory(self.api_instance)

    @property
    def pages(self) -> pages.PagesCategory:
        return pages.PagesCategory(self.api_instance)

    @property
    def photos(self) -> photos.PhotosCategory:
        return photos.PhotosCategory(self.api_instance)

    @property
    def polls(self) -> polls.PollsCategory:
        return polls.PollsCategory(self.api_instance)

    @property
    def prettyCards(self) -> prettyCards.PrettyCardsCategory:
        return prettyCards.PrettyCardsCategory(self.api_instance)

    @property
    def search(self) -> search.SearchCategory:
        return search.SearchCategory(self.api_instance)

    @property
    def secure(self) -> secure.SecureCategory:
        return secure.SecureCategory(self.api_instance)

    @property
    def stats(self) -> stats.StatsCategory:
        return stats.StatsCategory(self.api_instance)

    @property
    def status(self) -> status.StatusCategory:
        return status.StatusCategory(self.api_instance)

    @property
    def storage(self) -> storage.StorageCategory:
        return storage.StorageCategory(self.api_instance)

    @property
    def stories(self) -> stories.StoriesCategory:
        return stories.StoriesCategory(self.api_instance)

    @property
    def streaming(self) -> streaming.StreamingCategory:
        return streaming.StreamingCategory(self.api_instance)

    @property
    def users(self) -> users.UsersCategory:
        return users.UsersCategory(self.api_instance)

    @property
    def utils(self) -> utils.UtilsCategory:
        return utils.UtilsCategory(self.api_instance)

    @property
    def video(self) -> video.VideoCategory:
        return video.VideoCategory(self.api_instance)

    @property
    def wall(self) -> wall.WallCategory:
        return wall.WallCategory(self.api_instance)

    @property
    @abstractmethod
    def api_instance(self) -> "API":
        pass



from typing import Optional

from vkbottle_types.responses import auth, base
from .base_category import BaseCategory


class AuthCategory(BaseCategory):
    async def check_phone(
        self,
        phone: str,
        client_id: Optional[int] = None,
        client_secret: Optional[str] = None,
        auth_by_phone: Optional[bool] = None,
        **kwargs
    ) -> base.OkResponseModel:
        """Checks a user's phone number for correctness.
        :param phone: Phone number.
        :param client_id: User ID.
        :param client_secret:
        :param auth_by_phone:
        """

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("auth.checkPhone", params))

    async def restore(
        self, phone: str, last_name: str, **kwargs
    ) -> auth.RestoreResponseModel:
        """Allows to restore account access using a code received via SMS. " This method is only available for apps with [vk.com/dev/auth_direct|Direct authorization] access. "
        :param phone: User phone number.
        :param last_name: User last name.
        """

        params = self.get_set_params(locals())
        return auth.RestoreResponse(**await self.api.request("auth.restore", params))



from typing import Optional

from vkbottle_types.responses import likes
from .base_category import BaseCategory


class LikesCategory(BaseCategory):
    async def add(
        self,
        type: str,
        item_id: int,
        owner_id: Optional[int] = None,
        access_key: Optional[str] = None,
        **kwargs
    ) -> likes.AddResponseModel:
        """Adds the specified object to the 'Likes' list of the current user.
        :param type: Object type: 'post' — post on user or community wall, 'comment' — comment on a wall post, 'photo' — photo, 'audio' — audio, 'video' — video, 'note' — note, 'photo_comment' — comment on the photo, 'video_comment' — comment on the video, 'topic_comment' — comment in the discussion, 'sitepage' — page of the site where the [vk.com/dev/Like|Like widget] is installed
        :param item_id: Object ID.
        :param owner_id: ID of the user or community that owns the object.
        :param access_key: Access key required for an object owned by a private entity.
        """

        params = self.get_set_params(locals())
        return likes.AddResponse(**await self.api.request("likes.add", params))

    async def delete(
        self,
        type: str,
        item_id: int,
        owner_id: Optional[int] = None,
        access_key: Optional[str] = None,
        **kwargs
    ) -> likes.DeleteResponseModel:
        """Deletes the specified object from the 'Likes' list of the current user.
        :param type: Object type: 'post' — post on user or community wall, 'comment' — comment on a wall post, 'photo' — photo, 'audio' — audio, 'video' — video, 'note' — note, 'photo_comment' — comment on the photo, 'video_comment' — comment on the video, 'topic_comment' — comment in the discussion, 'sitepage' — page of the site where the [vk.com/dev/Like|Like widget] is installed
        :param item_id: Object ID.
        :param owner_id: ID of the user or community that owns the object.
        :param access_key: Access key required for an object owned by a private entity.
        """

        params = self.get_set_params(locals())
        return likes.DeleteResponse(**await self.api.request("likes.delete", params))

    async def get_list(
        self,
        type: str,
        owner_id: Optional[int] = None,
        item_id: Optional[int] = None,
        page_url: Optional[str] = None,
        filter: Optional[str] = None,
        friends_only: Optional[int] = None,
        extended: Optional[bool] = None,
        offset: Optional[int] = None,
        count: Optional[int] = None,
        skip_own: Optional[bool] = None,
        **kwargs
    ) -> likes.GetListExtendedResponseModel:
        """Returns a list of IDs of users who added the specified object to their 'Likes' list.
        :param type: , Object type: 'post' — post on user or community wall, 'comment' — comment on a wall post, 'photo' — photo, 'audio' — audio, 'video' — video, 'note' — note, 'photo_comment' — comment on the photo, 'video_comment' — comment on the video, 'topic_comment' — comment in the discussion, 'sitepage' — page of the site where the [vk.com/dev/Like|Like widget] is installed
        :param owner_id: ID of the user, community, or application that owns the object. If the 'type' parameter is set as 'sitepage', the application ID is passed as 'owner_id'. Use negative value for a community id. If the 'type' parameter is not set, the 'owner_id' is assumed to be either the current user or the same application ID as if the 'type' parameter was set to 'sitepage'.
        :param item_id: Object ID. If 'type' is set as 'sitepage', 'item_id' can include the 'page_id' parameter value used during initialization of the [vk.com/dev/Like|Like widget].
        :param page_url: URL of the page where the [vk.com/dev/Like|Like widget] is installed. Used instead of the 'item_id' parameter.
        :param filter: Filters to apply: 'likes' — returns information about all users who liked the object (default), 'copies' — returns information only about users who told their friends about the object
        :param friends_only: Specifies which users are returned: '1' — to return only the current user's friends, '0' — to return all users (default)
        :param extended: Specifies whether extended information will be returned. '1' — to return extended information about users and communities from the 'Likes' list, '0' — to return no additional information (default)
        :param offset: Offset needed to select a specific subset of users.
        :param count: Number of user IDs to return (maximum '1000'). Default is '100' if 'friends_only' is set to '0', otherwise, the default is '10' if 'friends_only' is set to '1'.
        :param skip_own:
        """

        params = self.get_set_params(locals())
        return likes.GetListExtendedResponse(
            **await self.api.request("likes.getList", params)
        )

    async def is_liked(
        self,
        type: str,
        item_id: int,
        user_id: Optional[int] = None,
        owner_id: Optional[int] = None,
        **kwargs
    ) -> likes.IsLikedResponseModel:
        """Checks for the object in the 'Likes' list of the specified user.
        :param type: Object type: 'post' — post on user or community wall, 'comment' — comment on a wall post, 'photo' — photo, 'audio' — audio, 'video' — video, 'note' — note, 'photo_comment' — comment on the photo, 'video_comment' — comment on the video, 'topic_comment' — comment in the discussion
        :param item_id: Object ID.
        :param user_id: User ID.
        :param owner_id: ID of the user or community that owns the object.
        """

        params = self.get_set_params(locals())
        return likes.IsLikedResponse(**await self.api.request("likes.isLiked", params))



from typing import Optional, List

from vkbottle_types.objects import (
    GroupsGroupFull,
    StoriesViewersItem,
    StoriesStoryStats,
    UsersUser,
    UsersUserFull,
    GroupsGroup,
    StoriesStory,
    StoriesFeedItem,
    StoriesPromoBlock,
)
from .base_response import BaseResponse


class GetBannedExtendedResponse(BaseResponse):
    response: Optional["GetBannedExtendedResponseModel"] = None


class GetBannedResponse(BaseResponse):
    response: Optional["GetBannedResponseModel"] = None


class GetByIdExtendedResponse(BaseResponse):
    response: Optional["GetByIdExtendedResponseModel"] = None


class GetByIdResponse(BaseResponse):
    response: Optional["GetByIdResponseModel"] = None


class GetPhotoUploadServerResponse(BaseResponse):
    response: Optional["GetPhotoUploadServerResponseModel"] = None


class GetStatsResponse(BaseResponse):
    response: Optional["GetStatsResponseModel"] = None


class GetVideoUploadServerResponse(BaseResponse):
    response: Optional["GetVideoUploadServerResponseModel"] = None


class GetViewersExtendedV5115Response(BaseResponse):
    response: Optional["GetViewersExtendedV5115ResponseModel"] = None


class GetViewersExtendedResponse(BaseResponse):
    response: Optional["GetViewersExtendedResponseModel"] = None


class GetV5113Response(BaseResponse):
    response: Optional["GetV5113ResponseModel"] = None


class GetResponse(BaseResponse):
    response: Optional["GetResponseModel"] = None


class UploadResponse(BaseResponse):
    response: Optional["UploadResponseModel"] = None


class GetBannedExtendedResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List[int]] = None
    profiles: Optional[List["UsersUserFull"]] = None
    groups: Optional[List["GroupsGroupFull"]] = None


class GetBannedResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List[int]] = None


class GetByIdExtendedResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["StoriesStory"]] = None
    profiles: Optional[List["UsersUserFull"]] = None
    groups: Optional[List["GroupsGroupFull"]] = None


class GetByIdResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["StoriesStory"]] = None


class GetPhotoUploadServerResponseModel(BaseResponse):
    upload_url: Optional[str] = None
    user_ids: Optional[List[int]] = None


GetStatsResponseModel = Optional[StoriesStoryStats]


class GetVideoUploadServerResponseModel(BaseResponse):
    upload_url: Optional[str] = None
    user_ids: Optional[List[int]] = None


class GetViewersExtendedV5115ResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["StoriesViewersItem"]] = None
    hidden_reason: Optional[str] = None


class GetViewersExtendedResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["UsersUserFull"]] = None


class GetV5113ResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["StoriesFeedItem"]] = None
    profiles: Optional[List["UsersUser"]] = None
    groups: Optional[List["GroupsGroup"]] = None
    need_upload_screen: Optional[bool] = None


class GetResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List[List["StoriesStory"]]] = None
    promo_data: Optional["StoriesPromoBlock"] = None
    profiles: Optional[List["UsersUser"]] = None
    groups: Optional[List["GroupsGroup"]] = None
    need_upload_screen: Optional[bool] = None


class UploadResponseModel(BaseResponse):
    upload_result: Optional[str] = None


GetBannedExtendedResponse.update_forward_refs()
GetBannedResponse.update_forward_refs()
GetByIdExtendedResponse.update_forward_refs()
GetByIdResponse.update_forward_refs()
GetPhotoUploadServerResponse.update_forward_refs()
GetStatsResponse.update_forward_refs()
GetVideoUploadServerResponse.update_forward_refs()
GetViewersExtendedV5115Response.update_forward_refs()
GetViewersExtendedResponse.update_forward_refs()
GetV5113Response.update_forward_refs()
GetResponse.update_forward_refs()
UploadResponse.update_forward_refs()



from typing import Optional, List

from vkbottle_types.objects import NotesNoteComment, NotesNote
from .base_response import BaseResponse


class AddResponse(BaseResponse):
    response: Optional["AddResponseModel"] = None


class CreateCommentResponse(BaseResponse):
    response: Optional["CreateCommentResponseModel"] = None


class GetByIdResponse(BaseResponse):
    response: Optional["GetByIdResponseModel"] = None


class GetCommentsResponse(BaseResponse):
    response: Optional["GetCommentsResponseModel"] = None


class GetResponse(BaseResponse):
    response: Optional["GetResponseModel"] = None


AddResponseModel = int

CreateCommentResponseModel = int

GetByIdResponseModel = Optional[NotesNote]


class GetCommentsResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["NotesNoteComment"]] = None


class GetResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["NotesNote"]] = None


AddResponse.update_forward_refs()
CreateCommentResponse.update_forward_refs()
GetByIdResponse.update_forward_refs()
GetCommentsResponse.update_forward_refs()
GetResponse.update_forward_refs()



from typing import Optional

from vkbottle_types.responses import pages, base
from .base_category import BaseCategory


class PagesCategory(BaseCategory):
    async def clear_cache(self, url: str, **kwargs) -> base.OkResponseModel:
        """Allows to clear the cache of particular 'external' pages which may be attached to VK posts.
        :param url: Address of the page where you need to refesh the cached version
        """

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("pages.clearCache", params))

    async def get(
        self,
        owner_id: Optional[int] = None,
        page_id: Optional[int] = None,
        global_: Optional[bool] = None,
        site_preview: Optional[bool] = None,
        title: Optional[str] = None,
        need_source: Optional[bool] = None,
        need_html: Optional[bool] = None,
        **kwargs
    ) -> pages.GetResponseModel:
        """Returns information about a wiki page.
        :param owner_id: Page owner ID.
        :param page_id: Wiki page ID.
        :param global: '1' — to return information about a global wiki page
        :param site_preview: '1' — resulting wiki page is a preview for the attached link
        :param title: Wiki page title.
        :param need_source:
        :param need_html: '1' — to return the page as HTML,
        """

        params = self.get_set_params(locals())
        return pages.GetResponse(**await self.api.request("pages.get", params))

    async def get_history(
        self,
        page_id: int,
        group_id: Optional[int] = None,
        user_id: Optional[int] = None,
        **kwargs
    ) -> pages.GetHistoryResponseModel:
        """Returns a list of all previous versions of a wiki page.
        :param page_id: Wiki page ID.
        :param group_id: ID of the community that owns the wiki page.
        :param user_id:
        """

        params = self.get_set_params(locals())
        return pages.GetHistoryResponse(
            **await self.api.request("pages.getHistory", params)
        )

    async def get_titles(
        self, group_id: Optional[int] = None, **kwargs
    ) -> pages.GetTitlesResponseModel:
        """Returns a list of wiki pages in a group.
        :param group_id: ID of the community that owns the wiki page.
        """

        params = self.get_set_params(locals())
        return pages.GetTitlesResponse(
            **await self.api.request("pages.getTitles", params)
        )

    async def get_version(
        self,
        version_id: int,
        group_id: Optional[int] = None,
        user_id: Optional[int] = None,
        need_html: Optional[bool] = None,
        **kwargs
    ) -> pages.GetVersionResponseModel:
        """Returns the text of one of the previous versions of a wiki page.
        :param version_id:
        :param group_id: ID of the community that owns the wiki page.
        :param user_id:
        :param need_html: '1' — to return the page as HTML
        """

        params = self.get_set_params(locals())
        return pages.GetVersionResponse(
            **await self.api.request("pages.getVersion", params)
        )

    async def parse_wiki(
        self, text: str, group_id: Optional[int] = None, **kwargs
    ) -> pages.ParseWikiResponseModel:
        """Returns HTML representation of the wiki markup.
        :param text: Text of the wiki page.
        :param group_id: ID of the group in the context of which this markup is interpreted.
        """

        params = self.get_set_params(locals())
        return pages.ParseWikiResponse(
            **await self.api.request("pages.parseWiki", params)
        )

    async def save(
        self,
        text: Optional[str] = None,
        page_id: Optional[int] = None,
        group_id: Optional[int] = None,
        user_id: Optional[int] = None,
        title: Optional[str] = None,
        **kwargs
    ) -> pages.SaveResponseModel:
        """Saves the text of a wiki page.
        :param text: Text of the wiki page in wiki-format.
        :param page_id: Wiki page ID. The 'title' parameter can be passed instead of 'pid'.
        :param group_id: ID of the community that owns the wiki page.
        :param user_id: User ID
        :param title: Wiki page title.
        """

        params = self.get_set_params(locals())
        return pages.SaveResponse(**await self.api.request("pages.save", params))

    async def save_access(
        self,
        page_id: int,
        group_id: Optional[int] = None,
        user_id: Optional[int] = None,
        view: Optional[int] = None,
        edit: Optional[int] = None,
        **kwargs
    ) -> pages.SaveAccessResponseModel:
        """Saves modified read and edit access settings for a wiki page.
        :param page_id: Wiki page ID.
        :param group_id: ID of the community that owns the wiki page.
        :param user_id:
        :param view: Who can view the wiki page: '1' — only community members, '2' — all users can view the page, '0' — only community managers
        :param edit: Who can edit the wiki page: '1' — only community members, '2' — all users can edit the page, '0' — only community managers
        """

        params = self.get_set_params(locals())
        return pages.SaveAccessResponse(
            **await self.api.request("pages.saveAccess", params)
        )



from typing import Optional, List

from vkbottle_types.objects import StatsWallpostStat, StatsPeriod
from .base_response import BaseResponse


class GetPostReachResponse(BaseResponse):
    response: Optional["GetPostReachResponseModel"] = None


class GetResponse(BaseResponse):
    response: Optional["GetResponseModel"] = None


GetPostReachResponseModel = List[StatsWallpostStat]

GetResponseModel = List[StatsPeriod]

GetPostReachResponse.update_forward_refs()
GetResponse.update_forward_refs()



from typing import Optional, List

from vkbottle_types.objects import (
    GroupsGroupFull,
    WallWallComment,
    UsersUser,
    UsersUserFull,
    GroupsGroup,
    WallWallpostFull,
)
from .base_response import BaseResponse


class CreateCommentResponse(BaseResponse):
    response: Optional["CreateCommentResponseModel"] = None


class EditResponse(BaseResponse):
    response: Optional["EditResponseModel"] = None


class GetByIdExtendedResponse(BaseResponse):
    response: Optional["GetByIdExtendedResponseModel"] = None


class GetByIdResponse(BaseResponse):
    response: Optional["GetByIdResponseModel"] = None


class GetCommentExtendedResponse(BaseResponse):
    response: Optional["GetCommentExtendedResponseModel"] = None


class GetCommentResponse(BaseResponse):
    response: Optional["GetCommentResponseModel"] = None


class GetCommentsExtendedResponse(BaseResponse):
    response: Optional["GetCommentsExtendedResponseModel"] = None


class GetCommentsResponse(BaseResponse):
    response: Optional["GetCommentsResponseModel"] = None


class GetRepostsResponse(BaseResponse):
    response: Optional["GetRepostsResponseModel"] = None


class GetExtendedResponse(BaseResponse):
    response: Optional["GetExtendedResponseModel"] = None


class GetResponse(BaseResponse):
    response: Optional["GetResponseModel"] = None


class PostAdsStealthResponse(BaseResponse):
    response: Optional["PostAdsStealthResponseModel"] = None


class PostResponse(BaseResponse):
    response: Optional["PostResponseModel"] = None


class RepostResponse(BaseResponse):
    response: Optional["RepostResponseModel"] = None


class SearchExtendedResponse(BaseResponse):
    response: Optional["SearchExtendedResponseModel"] = None


class SearchResponse(BaseResponse):
    response: Optional["SearchResponseModel"] = None


class CreateCommentResponseModel(BaseResponse):
    comment_id: Optional[int] = None


class EditResponseModel(BaseResponse):
    post_id: Optional[int] = None


class GetByIdExtendedResponseModel(BaseResponse):
    items: Optional[List["WallWallpostFull"]] = None
    profiles: Optional[List["UsersUserFull"]] = None
    groups: Optional[List["GroupsGroupFull"]] = None


GetByIdResponseModel = List[WallWallpostFull]


class GetCommentExtendedResponseModel(BaseResponse):
    items: Optional[List["WallWallComment"]] = None
    profiles: Optional[List["UsersUser"]] = None
    groups: Optional[List["GroupsGroup"]] = None


class GetCommentResponseModel(BaseResponse):
    items: Optional[List["WallWallComment"]] = None


class GetCommentsExtendedResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["WallWallComment"]] = None
    show_reply_button: Optional[bool] = None
    can_post: Optional[bool] = None
    groups_can_post: Optional[bool] = None
    current_level_count: Optional[int] = None
    profiles: Optional[List["UsersUser"]] = None
    groups: Optional[List["GroupsGroup"]] = None


class GetCommentsResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["WallWallComment"]] = None
    can_post: Optional[bool] = None
    groups_can_post: Optional[bool] = None
    current_level_count: Optional[int] = None


class GetRepostsResponseModel(BaseResponse):
    items: Optional[List["WallWallpostFull"]] = None
    profiles: Optional[List["UsersUser"]] = None
    groups: Optional[List["GroupsGroup"]] = None


class GetExtendedResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["WallWallpostFull"]] = None
    profiles: Optional[List["UsersUserFull"]] = None
    groups: Optional[List["GroupsGroupFull"]] = None


class GetResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["WallWallpostFull"]] = None


class PostAdsStealthResponseModel(BaseResponse):
    post_id: Optional[int] = None


class PostResponseModel(BaseResponse):
    post_id: Optional[int] = None


class RepostResponseModel(BaseResponse):
    success: Optional[int] = None
    post_id: Optional[int] = None
    reposts_count: Optional[int] = None
    likes_count: Optional[int] = None


class SearchExtendedResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["WallWallpostFull"]] = None
    profiles: Optional[List["UsersUserFull"]] = None
    groups: Optional[List["GroupsGroupFull"]] = None


class SearchResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["WallWallpostFull"]] = None


CreateCommentResponse.update_forward_refs()
EditResponse.update_forward_refs()
GetByIdExtendedResponse.update_forward_refs()
GetByIdResponse.update_forward_refs()
GetCommentExtendedResponse.update_forward_refs()
GetCommentResponse.update_forward_refs()
GetCommentsExtendedResponse.update_forward_refs()
GetCommentsResponse.update_forward_refs()
GetRepostsResponse.update_forward_refs()
GetExtendedResponse.update_forward_refs()
GetResponse.update_forward_refs()
PostAdsStealthResponse.update_forward_refs()
PostResponse.update_forward_refs()
RepostResponse.update_forward_refs()
SearchExtendedResponse.update_forward_refs()
SearchResponse.update_forward_refs()



from typing import Optional

from vkbottle_types.responses import base, utils
from .base_category import BaseCategory


class UtilsCategory(BaseCategory):
    async def check_link(self, url: str, **kwargs) -> utils.CheckLinkResponseModel:
        """Checks whether a link is blocked in VK.
        :param url: Link to check (e.g., 'http://google.com').
        """

        params = self.get_set_params(locals())
        return utils.CheckLinkResponse(
            **await self.api.request("utils.checkLink", params)
        )

    async def delete_from_last_shortened(
        self, key: str, **kwargs
    ) -> base.OkResponseModel:
        """Deletes shortened link from user's list.
        :param key: Link key (characters after vk.cc/).
        """

        params = self.get_set_params(locals())
        return base.OkResponse(
            **await self.api.request("utils.deleteFromLastShortened", params)
        )

    async def get_last_shortened_links(
        self, count: Optional[int] = None, offset: Optional[int] = None, **kwargs
    ) -> utils.GetLastShortenedLinksResponseModel:
        """Returns a list of user's shortened links.
        :param count: Number of links to return.
        :param offset: Offset needed to return a specific subset of links.
        """

        params = self.get_set_params(locals())
        return utils.GetLastShortenedLinksResponse(
            **await self.api.request("utils.getLastShortenedLinks", params)
        )

    async def get_link_stats(
        self,
        key: str,
        source: Optional[str] = None,
        access_key: Optional[str] = None,
        interval: Optional[str] = None,
        intervals_count: Optional[int] = None,
        extended: Optional[bool] = None,
        **kwargs
    ) -> utils.GetLinkStatsExtendedResponseModel:
        """Returns stats data for shortened link.
        :param key: Link key (characters after vk.cc/).
        :param source: Source of scope
        :param access_key: Access key for private link stats.
        :param interval: Interval.
        :param intervals_count: Number of intervals to return.
        :param extended: 1 — to return extended stats data (sex, age, geo). 0 — to return views number only.
        """

        params = self.get_set_params(locals())
        return utils.GetLinkStatsExtendedResponse(
            **await self.api.request("utils.getLinkStats", params)
        )

    async def get_server_time(self, **kwargs) -> utils.GetServerTimeResponseModel:
        """Returns the current time of the VK server."""

        params = self.get_set_params(locals())
        return utils.GetServerTimeResponse(
            **await self.api.request("utils.getServerTime", params)
        )

    async def get_short_link(
        self, url: str, private: Optional[bool] = None, **kwargs
    ) -> utils.GetShortLinkResponseModel:
        """Allows to receive a link shortened via vk.cc.
        :param url: URL to be shortened.
        :param private: 1 — private stats, 0 — public stats.
        """

        params = self.get_set_params(locals())
        return utils.GetShortLinkResponse(
            **await self.api.request("utils.getShortLink", params)
        )

    async def resolve_screen_name(
        self, screen_name: str, **kwargs
    ) -> utils.ResolveScreenNameResponseModel:
        """Detects a type of object (e.g., user, community, application, **kwargs) and its ID by screen name.
        :param screen_name: Screen name of the user, community (e.g., 'apiclub,' 'andrew', or 'rules_of_war'), or application.
        """

        params = self.get_set_params(locals())
        return utils.ResolveScreenNameResponse(
            **await self.api.request("utils.resolveScreenName", params)
        )



from typing import Optional, List

from vkbottle_types.responses import database
from .base_category import BaseCategory


class DatabaseCategory(BaseCategory):
    async def get_chairs(
        self,
        faculty_id: int,
        offset: Optional[int] = None,
        count: Optional[int] = None,
        **kwargs
    ) -> database.GetChairsResponseModel:
        """Returns list of chairs on a specified faculty.
        :param faculty_id: id of the faculty to get chairs from
        :param offset: offset required to get a certain subset of chairs
        :param count: amount of chairs to get
        """

        params = self.get_set_params(locals())
        return database.GetChairsResponse(
            **await self.api.request("database.getChairs", params)
        )

    async def get_cities(
        self,
        country_id: int,
        region_id: Optional[int] = None,
        q: Optional[str] = None,
        need_all: Optional[bool] = None,
        offset: Optional[int] = None,
        count: Optional[int] = None,
        **kwargs
    ) -> database.GetCitiesResponseModel:
        """Returns a list of cities.
        :param country_id: Country ID.
        :param region_id: Region ID.
        :param q: Search query.
        :param need_all: '1' — to return all cities in the country, '0' — to return major cities in the country (default),
        :param offset: Offset needed to return a specific subset of cities.
        :param count: Number of cities to return.
        """

        params = self.get_set_params(locals())
        return database.GetCitiesResponse(
            **await self.api.request("database.getCities", params)
        )

    async def get_cities_by_id(
        self, city_ids: Optional[List[int]] = None, **kwargs
    ) -> database.GetCitiesByIdResponseModel:
        """Returns information about cities by their IDs.
        :param city_ids: City IDs.
        """

        params = self.get_set_params(locals())
        return database.GetCitiesByIdResponse(
            **await self.api.request("database.getCitiesById", params)
        )

    async def get_countries(
        self,
        need_all: Optional[bool] = None,
        code: Optional[str] = None,
        offset: Optional[int] = None,
        count: Optional[int] = None,
        **kwargs
    ) -> database.GetCountriesResponseModel:
        """Returns a list of countries.
        :param need_all: '1' — to return a full list of all countries, '0' — to return a list of countries near the current user's country (default).
        :param code: Country codes in [vk.com/dev/country_codes|ISO 3166-1 alpha-2] standard.
        :param offset: Offset needed to return a specific subset of countries.
        :param count: Number of countries to return.
        """

        params = self.get_set_params(locals())
        return database.GetCountriesResponse(
            **await self.api.request("database.getCountries", params)
        )

    async def get_countries_by_id(
        self, country_ids: Optional[List[int]] = None, **kwargs
    ) -> database.GetCountriesByIdResponseModel:
        """Returns information about countries by their IDs.
        :param country_ids: Country IDs.
        """

        params = self.get_set_params(locals())
        return database.GetCountriesByIdResponse(
            **await self.api.request("database.getCountriesById", params)
        )

    async def get_faculties(
        self,
        university_id: int,
        offset: Optional[int] = None,
        count: Optional[int] = None,
        **kwargs
    ) -> database.GetFacultiesResponseModel:
        """Returns a list of faculties (i.e., university departments).
        :param university_id: University ID.
        :param offset: Offset needed to return a specific subset of faculties.
        :param count: Number of faculties to return.
        """

        params = self.get_set_params(locals())
        return database.GetFacultiesResponse(
            **await self.api.request("database.getFaculties", params)
        )

    async def get_metro_stations(
        self,
        city_id: int,
        offset: Optional[int] = None,
        count: Optional[int] = None,
        extended: Optional[bool] = None,
        **kwargs
    ) -> database.GetMetroStationsResponseModel:
        """Get metro stations by city
        :param city_id:
        :param offset:
        :param count:
        :param extended:
        """

        params = self.get_set_params(locals())
        return database.GetMetroStationsResponse(
            **await self.api.request("database.getMetroStations", params)
        )

    async def get_metro_stations_by_id(
        self, station_ids: Optional[List[int]] = None, **kwargs
    ) -> database.GetMetroStationsByIdResponseModel:
        """Get metro station by his id
        :param station_ids:
        """

        params = self.get_set_params(locals())
        return database.GetMetroStationsByIdResponse(
            **await self.api.request("database.getMetroStationsById", params)
        )

    async def get_regions(
        self,
        country_id: int,
        q: Optional[str] = None,
        offset: Optional[int] = None,
        count: Optional[int] = None,
        **kwargs
    ) -> database.GetRegionsResponseModel:
        """Returns a list of regions.
        :param country_id: Country ID, received in [vk.com/dev/database.getCountries|database.getCountries] method.
        :param q: Search query.
        :param offset: Offset needed to return specific subset of regions.
        :param count: Number of regions to return.
        """

        params = self.get_set_params(locals())
        return database.GetRegionsResponse(
            **await self.api.request("database.getRegions", params)
        )

    async def get_school_classes(
        self, country_id: Optional[int] = None, **kwargs
    ) -> database.GetSchoolClassesResponseModel:
        """Returns a list of school classes specified for the country.
        :param country_id: Country ID.
        """

        params = self.get_set_params(locals())
        return database.GetSchoolClassesResponse(
            **await self.api.request("database.getSchoolClasses", params)
        )

    async def get_schools(
        self,
        city_id: int,
        q: Optional[str] = None,
        offset: Optional[int] = None,
        count: Optional[int] = None,
        **kwargs
    ) -> database.GetSchoolsResponseModel:
        """Returns a list of schools.
        :param city_id: City ID.
        :param q: Search query.
        :param offset: Offset needed to return a specific subset of schools.
        :param count: Number of schools to return.
        """

        params = self.get_set_params(locals())
        return database.GetSchoolsResponse(
            **await self.api.request("database.getSchools", params)
        )

    async def get_universities(
        self,
        q: Optional[str] = None,
        country_id: Optional[int] = None,
        city_id: Optional[int] = None,
        offset: Optional[int] = None,
        count: Optional[int] = None,
        **kwargs
    ) -> database.GetUniversitiesResponseModel:
        """Returns a list of higher education institutions.
        :param q: Search query.
        :param country_id: Country ID.
        :param city_id: City ID.
        :param offset: Offset needed to return a specific subset of universities.
        :param count: Number of universities to return.
        """

        params = self.get_set_params(locals())
        return database.GetUniversitiesResponse(
            **await self.api.request("database.getUniversities", params)
        )



import typing
from typing import Optional, List

from vkbottle_types.responses import base, market
from .base_category import BaseCategory

if typing.TYPE_CHECKING:
    from vkbottle_types.objects import users as objects_users


class MarketCategory(BaseCategory):
    async def add(
        self,
        owner_id: int,
        name: str,
        description: str,
        category_id: int,
        main_photo_id: int,
        price: Optional[float] = None,
        old_price: Optional[float] = None,
        deleted: Optional[bool] = None,
        photo_ids: Optional[List[int]] = None,
        url: Optional[str] = None,
        dimension_width: Optional[int] = None,
        dimension_height: Optional[int] = None,
        dimension_length: Optional[int] = None,
        weight: Optional[int] = None,
        **kwargs
    ) -> market.AddResponseModel:
        """Ads a new item to the market.
        :param owner_id: ID of an item owner community.
        :param name: Item name.
        :param description: Item description.
        :param category_id: Item category ID.
        :param main_photo_id: Cover photo ID.
        :param price: Item price.
        :param old_price:
        :param deleted: Item status ('1' — deleted, '0' — not deleted).
        :param photo_ids: IDs of additional photos.
        :param url: Url for button in market item.
        :param dimension_width:
        :param dimension_height:
        :param dimension_length:
        :param weight:
        """

        params = self.get_set_params(locals())
        return market.AddResponse(**await self.api.request("market.add", params))

    async def add_album(
        self,
        owner_id: int,
        title: str,
        photo_id: Optional[int] = None,
        main_album: Optional[bool] = None,
        **kwargs
    ) -> market.AddAlbumResponseModel:
        """Creates new collection of items
        :param owner_id: ID of an item owner community.
        :param title: Collection title.
        :param photo_id: Cover photo ID.
        :param main_album: Set as main ('1' – set, '0' – no).
        """

        params = self.get_set_params(locals())
        return market.AddAlbumResponse(
            **await self.api.request("market.addAlbum", params)
        )

    async def add_to_album(
        self, owner_id: int, item_id: int, album_ids: List[int], **kwargs
    ) -> base.OkResponseModel:
        """Adds an item to one or multiple collections.
        :param owner_id: ID of an item owner community.
        :param item_id: Item ID.
        :param album_ids: Collections IDs to add item to.
        """

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("market.addToAlbum", params))

    async def create_comment(
        self,
        owner_id: int,
        item_id: int,
        message: Optional[str] = None,
        attachments: Optional[List[str]] = None,
        from_group: Optional[bool] = None,
        reply_to_comment: Optional[int] = None,
        sticker_id: Optional[int] = None,
        guid: Optional[str] = None,
        **kwargs
    ) -> market.CreateCommentResponseModel:
        """Creates a new comment for an item.
        :param owner_id: ID of an item owner community.
        :param item_id: Item ID.
        :param message: Comment text (required if 'attachments' parameter is not specified)
        :param attachments: Comma-separated list of objects attached to a comment. The field is submitted the following way: , "'<owner_id>_<media_id>,<owner_id>_<media_id>'", , '' - media attachment type: "'photo' - photo, 'video' - video, 'audio' - audio, 'doc' - document", , '<owner_id>' - media owner id, '<media_id>' - media attachment id, , For example: "photo100172_166443618,photo66748_265827614",
        :param from_group: '1' - comment will be published on behalf of a community, '0' - on behalf of a user (by default).
        :param reply_to_comment: ID of a comment to reply with current comment to.
        :param sticker_id: Sticker ID.
        :param guid: Random value to avoid resending one comment.
        """

        params = self.get_set_params(locals())
        return market.CreateCommentResponse(
            **await self.api.request("market.createComment", params)
        )

    async def delete(
        self, owner_id: int, item_id: int, **kwargs
    ) -> base.OkResponseModel:
        """Deletes an item.
        :param owner_id: ID of an item owner community.
        :param item_id: Item ID.
        """

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("market.delete", params))

    async def delete_album(
        self, owner_id: int, album_id: int, **kwargs
    ) -> base.OkResponseModel:
        """Deletes a collection of items.
        :param owner_id: ID of an collection owner community.
        :param album_id: Collection ID.
        """

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("market.deleteAlbum", params))

    async def delete_comment(
        self, owner_id: int, comment_id: int, **kwargs
    ) -> market.DeleteCommentResponseModel:
        """Deletes an item's comment
        :param owner_id: identifier of an item owner community, "Note that community id in the 'owner_id' parameter should be negative number. For example 'owner_id'=-1 matches the [vk.com/apiclub|VK API] community "
        :param comment_id: comment id
        """

        params = self.get_set_params(locals())
        return market.DeleteCommentResponse(
            **await self.api.request("market.deleteComment", params)
        )

    async def edit(
        self,
        owner_id: int,
        item_id: int,
        name: str,
        description: str,
        category_id: int,
        price: float,
        main_photo_id: int,
        deleted: Optional[bool] = None,
        photo_ids: Optional[List[int]] = None,
        url: Optional[str] = None,
        **kwargs
    ) -> base.OkResponseModel:
        """Edits an item.
        :param owner_id: ID of an item owner community.
        :param item_id: Item ID.
        :param name: Item name.
        :param description: Item description.
        :param category_id: Item category ID.
        :param price: Item price.
        :param main_photo_id: Cover photo ID.
        :param deleted: Item status ('1' — deleted, '0' — not deleted).
        :param photo_ids: IDs of additional photos.
        :param url: Url for button in market item.
        """

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("market.edit", params))

    async def edit_album(
        self,
        owner_id: int,
        album_id: int,
        title: str,
        photo_id: Optional[int] = None,
        main_album: Optional[bool] = None,
        **kwargs
    ) -> base.OkResponseModel:
        """Edits a collection of items
        :param owner_id: ID of an collection owner community.
        :param album_id: Collection ID.
        :param title: Collection title.
        :param photo_id: Cover photo id
        :param main_album: Set as main ('1' – set, '0' – no).
        """

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("market.editAlbum", params))

    async def edit_comment(
        self,
        owner_id: int,
        comment_id: int,
        message: Optional[str] = None,
        attachments: Optional[List[str]] = None,
        **kwargs
    ) -> base.OkResponseModel:
        """Chages item comment's text
        :param owner_id: ID of an item owner community.
        :param comment_id: Comment ID.
        :param message: New comment text (required if 'attachments' are not specified), , 2048 symbols maximum.
        :param attachments: Comma-separated list of objects attached to a comment. The field is submitted the following way: , "'<owner_id>_<media_id>,<owner_id>_<media_id>'", , '' - media attachment type: "'photo' - photo, 'video' - video, 'audio' - audio, 'doc' - document", , '<owner_id>' - media owner id, '<media_id>' - media attachment id, , For example: "photo100172_166443618,photo66748_265827614",
        """

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("market.editComment", params))

    async def get(
        self,
        owner_id: int,
        album_id: Optional[int] = None,
        count: Optional[int] = None,
        offset: Optional[int] = None,
        extended: Optional[bool] = None,
        **kwargs
    ) -> market.GetExtendedResponseModel:
        """Returns items list for a community.
        :param owner_id: ID of an item owner community, "Note that community id in the 'owner_id' parameter should be negative number. For example 'owner_id'=-1 matches the [vk.com/apiclub|VK API] community "
        :param album_id:
        :param count: Number of items to return.
        :param offset: Offset needed to return a specific subset of results.
        :param extended: '1' – method will return additional fields: 'likes, can_comment, car_repost, photos'. These parameters are not returned by default.
        """

        params = self.get_set_params(locals())
        return market.GetExtendedResponse(
            **await self.api.request("market.get", params)
        )

    async def get_album_by_id(
        self, owner_id: int, album_ids: List[int], **kwargs
    ) -> market.GetAlbumByIdResponseModel:
        """Returns items album's data
        :param owner_id: identifier of an album owner community, "Note that community id in the 'owner_id' parameter should be negative number. For example 'owner_id'=-1 matches the [vk.com/apiclub|VK API] community "
        :param album_ids: collections identifiers to obtain data from
        """

        params = self.get_set_params(locals())
        return market.GetAlbumByIdResponse(
            **await self.api.request("market.getAlbumById", params)
        )

    async def get_albums(
        self,
        owner_id: int,
        offset: Optional[int] = None,
        count: Optional[int] = None,
        **kwargs
    ) -> market.GetAlbumsResponseModel:
        """Returns community's collections list.
        :param owner_id: ID of an items owner community.
        :param offset: Offset needed to return a specific subset of results.
        :param count: Number of items to return.
        """

        params = self.get_set_params(locals())
        return market.GetAlbumsResponse(
            **await self.api.request("market.getAlbums", params)
        )

    async def get_by_id(
        self, item_ids: List[str], extended: Optional[bool] = None, **kwargs
    ) -> market.GetByIdExtendedResponseModel:
        """Returns information about market items by their ids.
        :param item_ids: Comma-separated ids list: {user id}_{item id}. If an item belongs to a community -{community id} is used. " 'Videos' value example: , '-4363_136089719,13245770_137352259'"
        :param extended: '1' – to return additional fields: 'likes, can_comment, car_repost, photos'. By default: '0'.
        """

        params = self.get_set_params(locals())
        return market.GetByIdExtendedResponse(
            **await self.api.request("market.getById", params)
        )

    async def get_categories(
        self, count: Optional[int] = None, offset: Optional[int] = None, **kwargs
    ) -> market.GetCategoriesResponseModel:
        """Returns a list of market categories.
        :param count: Number of results to return.
        :param offset: Offset needed to return a specific subset of results.
        """

        params = self.get_set_params(locals())
        return market.GetCategoriesResponse(
            **await self.api.request("market.getCategories", params)
        )

    async def get_comments(
        self,
        owner_id: int,
        item_id: int,
        need_likes: Optional[bool] = None,
        start_comment_id: Optional[int] = None,
        offset: Optional[int] = None,
        count: Optional[int] = None,
        sort: Optional[str] = None,
        extended: Optional[bool] = None,
        fields: Optional[List["objects_users.Fields"]] = None,
        **kwargs
    ) -> market.GetCommentsResponseModel:
        """Returns comments list for an item.
        :param owner_id: ID of an item owner community
        :param item_id: Item ID.
        :param need_likes: '1' — to return likes info.
        :param start_comment_id: ID of a comment to start a list from (details below).
        :param offset:
        :param count: Number of results to return.
        :param sort: Sort order ('asc' — from old to new, 'desc' — from new to old)
        :param extended: '1' — comments will be returned as numbered objects, in addition lists of 'profiles' and 'groups' objects will be returned.
        :param fields: List of additional profile fields to return. See the [vk.com/dev/fields|details]
        """

        params = self.get_set_params(locals())
        return market.GetCommentsResponse(
            **await self.api.request("market.getComments", params)
        )

    async def remove_from_album(
        self, owner_id: int, item_id: int, album_ids: List[int], **kwargs
    ) -> base.OkResponseModel:
        """Removes an item from one or multiple collections.
        :param owner_id: ID of an item owner community.
        :param item_id: Item ID.
        :param album_ids: Collections IDs to remove item from.
        """

        params = self.get_set_params(locals())
        return base.OkResponse(
            **await self.api.request("market.removeFromAlbum", params)
        )

    async def reorder_albums(
        self,
        owner_id: int,
        album_id: int,
        before: Optional[int] = None,
        after: Optional[int] = None,
        **kwargs
    ) -> base.OkResponseModel:
        """Reorders the collections list.
        :param owner_id: ID of an item owner community.
        :param album_id: Collection ID.
        :param before: ID of a collection to place current collection before it.
        :param after: ID of a collection to place current collection after it.
        """

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("market.reorderAlbums", params))

    async def reorder_items(
        self,
        owner_id: int,
        item_id: int,
        album_id: Optional[int] = None,
        before: Optional[int] = None,
        after: Optional[int] = None,
        **kwargs
    ) -> base.OkResponseModel:
        """Changes item place in a collection.
        :param owner_id: ID of an item owner community.
        :param item_id: Item ID.
        :param album_id: ID of a collection to reorder items in. Set 0 to reorder full items list.
        :param before: ID of an item to place current item before it.
        :param after: ID of an item to place current item after it.
        """

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("market.reorderItems", params))

    async def report(
        self, owner_id: int, item_id: int, reason: Optional[int] = None, **kwargs
    ) -> base.OkResponseModel:
        """Sends a complaint to the item.
        :param owner_id: ID of an item owner community.
        :param item_id: Item ID.
        :param reason: Complaint reason. Possible values: *'0' — spam,, *'1' — child porn,, *'2' — extremism,, *'3' — violence,, *'4' — drugs propaganda,, *'5' — adult materials,, *'6' — insult.
        """

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("market.report", params))

    async def report_comment(
        self, owner_id: int, comment_id: int, reason: int, **kwargs
    ) -> base.OkResponseModel:
        """Sends a complaint to the item's comment.
        :param owner_id: ID of an item owner community.
        :param comment_id: Comment ID.
        :param reason: Complaint reason. Possible values: *'0' — spam,, *'1' — child porn,, *'2' — extremism,, *'3' — violence,, *'4' — drugs propaganda,, *'5' — adult materials,, *'6' — insult.
        """

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("market.reportComment", params))

    async def restore(
        self, owner_id: int, item_id: int, **kwargs
    ) -> base.OkResponseModel:
        """Restores recently deleted item
        :param owner_id: ID of an item owner community.
        :param item_id: Deleted item ID.
        """

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("market.restore", params))

    async def restore_comment(
        self, owner_id: int, comment_id: int, **kwargs
    ) -> market.RestoreCommentResponseModel:
        """Restores a recently deleted comment
        :param owner_id: identifier of an item owner community, "Note that community id in the 'owner_id' parameter should be negative number. For example 'owner_id'=-1 matches the [vk.com/apiclub|VK API] community "
        :param comment_id: deleted comment id
        """

        params = self.get_set_params(locals())
        return market.RestoreCommentResponse(
            **await self.api.request("market.restoreComment", params)
        )

    async def search(
        self,
        owner_id: int,
        album_id: Optional[int] = None,
        q: Optional[str] = None,
        price_from: Optional[int] = None,
        price_to: Optional[int] = None,
        sort: Optional[int] = None,
        rev: Optional[int] = None,
        offset: Optional[int] = None,
        count: Optional[int] = None,
        extended: Optional[bool] = None,
        status: Optional[int] = None,
        **kwargs
    ) -> market.SearchExtendedResponseModel:
        """Searches market items in a community's catalog
        :param owner_id: ID of an items owner community.
        :param album_id:
        :param q: Search query, for example "pink slippers".
        :param price_from: Minimum item price value.
        :param price_to: Maximum item price value.
        :param sort:
        :param rev: '0' — do not use reverse order, '1' — use reverse order
        :param offset: Offset needed to return a specific subset of results.
        :param count: Number of items to return.
        :param extended: '1' – to return additional fields: 'likes, can_comment, car_repost, photos'. By default: '0'.
        :param status:
        """

        params = self.get_set_params(locals())
        return market.SearchExtendedResponse(
            **await self.api.request("market.search", params)
        )



from typing import Optional, List, Union

from vkbottle_types.objects import (
    GroupsGroupFull,
    NewsfeedNewsfeedItem,
    WallWallpostToId,
    UsersUserFull,
    UsersUserXtrType,
    WallWallpostFull,
    NewsfeedListFull,
    NewsfeedList,
)
from .base_response import BaseResponse


class GetBannedExtendedResponse(BaseResponse):
    response: Optional["GetBannedExtendedResponseModel"] = None


class GetBannedResponse(BaseResponse):
    response: Optional["GetBannedResponseModel"] = None


class GetCommentsResponse(BaseResponse):
    response: Optional["GetCommentsResponseModel"] = None


class GetListsExtendedResponse(BaseResponse):
    response: Optional["GetListsExtendedResponseModel"] = None


class GetListsResponse(BaseResponse):
    response: Optional["GetListsResponseModel"] = None


class GetMentionsResponse(BaseResponse):
    response: Optional["GetMentionsResponseModel"] = None


class GetRecommendedResponse(BaseResponse):
    response: Optional["GetRecommendedResponseModel"] = None


class GetSuggestedSourcesResponse(BaseResponse):
    response: Optional["GetSuggestedSourcesResponseModel"] = None


class GetResponse(BaseResponse):
    response: Optional["GetResponseModel"] = None


class SaveListResponse(BaseResponse):
    response: Optional["SaveListResponseModel"] = None


class SearchExtendedResponse(BaseResponse):
    response: Optional["SearchExtendedResponseModel"] = None


class SearchResponse(BaseResponse):
    response: Optional["SearchResponseModel"] = None


class GetBannedExtendedResponseModel(BaseResponse):
    groups: Optional[List["UsersUserFull"]] = None
    profiles: Optional[List["GroupsGroupFull"]] = None


class GetBannedResponseModel(BaseResponse):
    groups: Optional[List[int]] = None
    members: Optional[List[int]] = None


class GetCommentsResponseModel(BaseResponse):
    items: Optional[List["NewsfeedNewsfeedItem"]] = None
    profiles: Optional[List["UsersUserFull"]] = None
    groups: Optional[List["GroupsGroupFull"]] = None
    next_from: Optional[str] = None


class GetListsExtendedResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["NewsfeedListFull"]] = None


class GetListsResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["NewsfeedList"]] = None


class GetMentionsResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["WallWallpostToId"]] = None


class GetRecommendedResponseModel(BaseResponse):
    items: Optional[List["NewsfeedNewsfeedItem"]] = None
    profiles: Optional[List["UsersUserFull"]] = None
    groups: Optional[List["GroupsGroupFull"]] = None
    new_offset: Optional[str] = None
    next_from: Optional[str] = None


class GetSuggestedSourcesResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[Union["GroupsGroupFull", "UsersUserXtrType"]] = None


class GetResponseModel(BaseResponse):
    items: Optional[List["NewsfeedNewsfeedItem"]] = None
    profiles: Optional[List["UsersUserFull"]] = None
    groups: Optional[List["GroupsGroupFull"]] = None
    next_from: Optional[str] = None


SaveListResponseModel = int


class SearchExtendedResponseModel(BaseResponse):
    items: Optional[List["WallWallpostFull"]] = None
    profiles: Optional[List["UsersUserFull"]] = None
    groups: Optional[List["GroupsGroupFull"]] = None
    suggested_queries: Optional[List[str]] = None
    next_from: Optional[str] = None
    count: Optional[int] = None
    total_count: Optional[int] = None


class SearchResponseModel(BaseResponse):
    items: Optional[List["WallWallpostFull"]] = None
    suggested_queries: Optional[List[str]] = None
    next_from: Optional[str] = None
    count: Optional[int] = None
    total_count: Optional[int] = None


GetBannedExtendedResponse.update_forward_refs()
GetBannedResponse.update_forward_refs()
GetCommentsResponse.update_forward_refs()
GetListsExtendedResponse.update_forward_refs()
GetListsResponse.update_forward_refs()
GetMentionsResponse.update_forward_refs()
GetRecommendedResponse.update_forward_refs()
GetSuggestedSourcesResponse.update_forward_refs()
GetResponse.update_forward_refs()
SaveListResponse.update_forward_refs()
SearchExtendedResponse.update_forward_refs()
SearchResponse.update_forward_refs()



from typing import Optional

from vkbottle_types.responses import status, base
from .base_category import BaseCategory


class StatusCategory(BaseCategory):
    async def get(
        self, user_id: Optional[int] = None, group_id: Optional[int] = None, **kwargs
    ) -> status.GetResponseModel:
        """Returns data required to show the status of a user or community.
        :param user_id: User ID or community ID. Use a negative value to designate a community ID.
        :param group_id:
        """

        params = self.get_set_params(locals())
        return status.GetResponse(**await self.api.request("status.get", params))

    async def set(
        self, text: Optional[str] = None, group_id: Optional[int] = None, **kwargs
    ) -> base.OkResponseModel:
        """Sets a new status for the current user.
        :param text: Text of the new status.
        :param group_id: Identifier of a community to set a status in. If left blank the status is set to current user.
        """

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("status.set", params))



from typing import Optional, List, Union

from vkbottle_types.objects import (
    DatabaseUniversity,
    BaseObject,
    DatabaseSchool,
    BaseCountry,
    DatabaseCity,
    DatabaseFaculty,
    DatabaseStation,
    DatabaseRegion,
)
from .base_response import BaseResponse


class GetChairsResponse(BaseResponse):
    response: Optional["GetChairsResponseModel"] = None


class GetCitiesByIdResponse(BaseResponse):
    response: Optional["GetCitiesByIdResponseModel"] = None


class GetCitiesResponse(BaseResponse):
    response: Optional["GetCitiesResponseModel"] = None


class GetCountriesByIdResponse(BaseResponse):
    response: Optional["GetCountriesByIdResponseModel"] = None


class GetCountriesResponse(BaseResponse):
    response: Optional["GetCountriesResponseModel"] = None


class GetFacultiesResponse(BaseResponse):
    response: Optional["GetFacultiesResponseModel"] = None


class GetMetroStationsByIdResponse(BaseResponse):
    response: Optional["GetMetroStationsByIdResponseModel"] = None


class GetMetroStationsResponse(BaseResponse):
    response: Optional["GetMetroStationsResponseModel"] = None


class GetRegionsResponse(BaseResponse):
    response: Optional["GetRegionsResponseModel"] = None


class GetSchoolClassesResponse(BaseResponse):
    response: Optional["GetSchoolClassesResponseModel"] = None


class GetSchoolsResponse(BaseResponse):
    response: Optional["GetSchoolsResponseModel"] = None


class GetUniversitiesResponse(BaseResponse):
    response: Optional["GetUniversitiesResponseModel"] = None


class GetChairsResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["BaseObject"]] = None


GetCitiesByIdResponseModel = List[BaseObject]


class GetCitiesResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["DatabaseCity"]] = None


GetCountriesByIdResponseModel = List[BaseCountry]


class GetCountriesResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["BaseCountry"]] = None


class GetFacultiesResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["DatabaseFaculty"]] = None


GetMetroStationsByIdResponseModel = List[DatabaseStation]


class GetMetroStationsResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["DatabaseStation"]] = None


class GetRegionsResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["DatabaseRegion"]] = None


GetSchoolClassesResponseModel = List[List[Union[str, int]]]


class GetSchoolsResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["DatabaseSchool"]] = None


class GetUniversitiesResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["DatabaseUniversity"]] = None


GetChairsResponse.update_forward_refs()
GetCitiesByIdResponse.update_forward_refs()
GetCitiesResponse.update_forward_refs()
GetCountriesByIdResponse.update_forward_refs()
GetCountriesResponse.update_forward_refs()
GetFacultiesResponse.update_forward_refs()
GetMetroStationsByIdResponse.update_forward_refs()
GetMetroStationsResponse.update_forward_refs()
GetRegionsResponse.update_forward_refs()
GetSchoolClassesResponse.update_forward_refs()
GetSchoolsResponse.update_forward_refs()
GetUniversitiesResponse.update_forward_refs()



from typing import Optional, List

from vkbottle_types.objects import PollsVoters, PollsPoll, BaseBoolInt
from .base_response import BaseResponse


class AddVoteResponse(BaseResponse):
    response: Optional["AddVoteResponseModel"] = None


class CreateResponse(BaseResponse):
    response: Optional["CreateResponseModel"] = None


class DeleteVoteResponse(BaseResponse):
    response: Optional["DeleteVoteResponseModel"] = None


class GetByIdResponse(BaseResponse):
    response: Optional["GetByIdResponseModel"] = None


class GetVotersResponse(BaseResponse):
    response: Optional["GetVotersResponseModel"] = None


AddVoteResponseModel = Optional[BaseBoolInt]

CreateResponseModel = Optional[PollsPoll]

DeleteVoteResponseModel = Optional[BaseBoolInt]

GetByIdResponseModel = Optional[PollsPoll]

GetVotersResponseModel = List[PollsVoters]

AddVoteResponse.update_forward_refs()
CreateResponse.update_forward_refs()
DeleteVoteResponse.update_forward_refs()
GetByIdResponse.update_forward_refs()
GetVotersResponse.update_forward_refs()



from typing import Optional

from vkbottle_types.responses import downloadedGames
from .base_category import BaseCategory


class DownloadedGamesCategory(BaseCategory):
    async def get_paid_status(
        self, user_id: Optional[int] = None, **kwargs
    ) -> downloadedGames.PaidStatusResponseModel:
        """downloadedGames.getPaidStatus method
        :param user_id:
        """

        params = self.get_set_params(locals())
        return downloadedGames.PaidStatusResponse(
            **await self.api.request("downloadedGames.getPaidStatus", params)
        )



import typing
from typing import Optional, List

from vkbottle_types.responses import apps, base
from .base_category import BaseCategory

if typing.TYPE_CHECKING:
    from vkbottle_types.objects import users as objects_users


class AppsCategory(BaseCategory):
    async def delete_app_requests(self, **kwargs) -> base.OkResponseModel:
        """Deletes all request notifications from the current app."""

        params = self.get_set_params(locals())
        return base.OkResponse(
            **await self.api.request("apps.deleteAppRequests", params)
        )

    async def get(
        self,
        app_id: Optional[int] = None,
        app_ids: Optional[List[str]] = None,
        platform: Optional[str] = None,
        extended: Optional[bool] = None,
        return_friends: Optional[bool] = None,
        fields: Optional[List["objects_users.Fields"]] = None,
        name_case: Optional[str] = None,
        **kwargs
    ) -> apps.GetResponseModel:
        """Returns applications data.
        :param app_id: Application ID
        :param app_ids: List of application ID
        :param platform: platform. Possible values: *'ios' — iOS,, *'android' — Android,, *'winphone' — Windows Phone,, *'web' — приложения на vk.com. By default: 'web'.
        :param extended:
        :param return_friends:
        :param fields: Profile fields to return. Sample values: 'nickname', 'screen_name', 'sex', 'bdate' (birthdate), 'city', 'country', 'timezone', 'photo', 'photo_medium', 'photo_big', 'has_mobile', 'contacts', 'education', 'online', 'counters', 'relation', 'last_seen', 'activity', 'can_write_private_message', 'can_see_all_posts', 'can_post', 'universities', (only if return_friends - 1)
        :param name_case: Case for declension of user name and surname: 'nom' — nominative (default),, 'gen' — genitive,, 'dat' — dative,, 'acc' — accusative,, 'ins' — instrumental,, 'abl' — prepositional. (only if 'return_friends' = '1')
        """

        params = self.get_set_params(locals())
        return apps.GetResponse(**await self.api.request("apps.get", params))

    async def get_catalog(
        self,
        count: int,
        sort: Optional[str] = None,
        offset: Optional[int] = None,
        platform: Optional[str] = None,
        extended: Optional[bool] = None,
        return_friends: Optional[bool] = None,
        fields: Optional[List["objects_users.Fields"]] = None,
        name_case: Optional[str] = None,
        q: Optional[str] = None,
        genre_id: Optional[int] = None,
        filter: Optional[str] = None,
        **kwargs
    ) -> apps.GetCatalogResponseModel:
        """Returns a list of applications (apps, **kwargs) available to users in the App Catalog.
        :param count: Number of apps to return.
        :param sort: Sort order: 'popular_today' — popular for one day (default), 'visitors' — by visitors number , 'create_date' — by creation date, 'growth_rate' — by growth rate, 'popular_week' — popular for one week
        :param offset: Offset required to return a specific subset of apps.
        :param platform:
        :param extended: '1' — to return additional fields 'screenshots', 'MAU', 'catalog_position', and 'international'. If set, 'count' must be less than or equal to '100'. '0' — not to return additional fields (default).
        :param return_friends:
        :param fields:
        :param name_case:
        :param q: Search query string.
        :param genre_id:
        :param filter: 'installed' — to return list of installed apps (only for mobile platform).
        """

        params = self.get_set_params(locals())
        return apps.GetCatalogResponse(
            **await self.api.request("apps.getCatalog", params)
        )

    async def get_friends_list(
        self,
        extended: Optional[bool] = None,
        count: Optional[int] = None,
        offset: Optional[int] = None,
        type: Optional[str] = None,
        fields: Optional[List["objects_users.Fields"]] = None,
        **kwargs
    ) -> apps.GetFriendsListResponseModel:
        """Creates friends list for requests and invites in current app.
        :param extended:
        :param count: List size.
        :param offset:
        :param type: List type. Possible values: * 'invite' — available for invites (don't play the game),, * 'request' — available for request (play the game). By default: 'invite'.
        :param fields: Additional profile fields, see [vk.com/dev/fields|description].
        """

        params = self.get_set_params(locals())
        return apps.GetFriendsListResponse(
            **await self.api.request("apps.getFriendsList", params)
        )

    async def get_leaderboard(
        self,
        type: str,
        global_: Optional[bool] = None,
        extended: Optional[bool] = None,
        **kwargs
    ) -> apps.GetLeaderboardExtendedResponseModel:
        """Returns players rating in the game.
        :param type: Leaderboard type. Possible values: *'level' — by level,, *'points' — by mission points,, *'score' — by score ().
        :param global: Rating type. Possible values: *'1' — global rating among all players,, *'0' — rating among user friends.
        :param extended: 1 — to return additional info about users
        """

        params = self.get_set_params(locals())
        return apps.GetLeaderboardExtendedResponse(
            **await self.api.request("apps.getLeaderboard", params)
        )

    async def get_scopes(
        self, type: Optional[str] = None, **kwargs
    ) -> apps.GetScopesResponseModel:
        """Returns scopes for auth
        :param type:
        """

        params = self.get_set_params(locals())
        return apps.GetScopesResponse(
            **await self.api.request("apps.getScopes", params)
        )

    async def get_score(self, user_id: int, **kwargs) -> apps.GetScoreResponseModel:
        """Returns user score in app
        :param user_id:
        """

        params = self.get_set_params(locals())
        return apps.GetScoreResponse(**await self.api.request("apps.getScore", params))

    async def promo_has_active_gift(
        self, promo_id: int, user_id: Optional[int] = None, **kwargs
    ) -> base.BoolResponseModel:
        """apps.promoHasActiveGift method
        :param promo_id: Id of game promo action
        :param user_id:
        """

        params = self.get_set_params(locals())
        return base.BoolResponse(
            **await self.api.request("apps.promoHasActiveGift", params)
        )

    async def promo_use_gift(
        self, promo_id: int, user_id: Optional[int] = None, **kwargs
    ) -> base.BoolResponseModel:
        """apps.promoUseGift method
        :param promo_id: Id of game promo action
        :param user_id:
        """

        params = self.get_set_params(locals())
        return base.BoolResponse(**await self.api.request("apps.promoUseGift", params))

    async def send_request(
        self,
        user_id: int,
        text: Optional[str] = None,
        type: Optional[str] = None,
        name: Optional[str] = None,
        key: Optional[str] = None,
        separate: Optional[bool] = None,
        **kwargs
    ) -> apps.SendRequestResponseModel:
        """Sends a request to another user in an app that uses VK authorization.
        :param user_id: id of the user to send a request
        :param text: request text
        :param type: request type. Values: 'invite' – if the request is sent to a user who does not have the app installed,, 'request' – if a user has already installed the app
        :param name:
        :param key: special string key to be sent with the request
        :param separate:
        """

        params = self.get_set_params(locals())
        return apps.SendRequestResponse(
            **await self.api.request("apps.sendRequest", params)
        )



from typing import Optional, List

from vkbottle_types.objects import (
    AdsTargSettings,
    AdsTargStats,
    AdsRejectReason,
    AdsFloodStats,
    AdsCampaign,
    AdsTargSuggestions,
    AdsDemoStats,
    AdsCategory,
    AdsStats,
    AdsUsers,
    AdsTargSuggestionsRegions,
    AdsAccount,
    AdsAd,
    AdsTargSuggestionsSchools,
    AdsLookalikeRequest,
    AdsPromotedPostReach,
    AdsAdLayout,
    AdsMusician,
    AdsTargetGroup,
    AdsTargSuggestionsCities,
    AdsLinkStatus,
    AdsClient,
)
from .base_response import BaseResponse


class AddOfficeUsersResponse(BaseResponse):
    response: Optional["AddOfficeUsersResponseModel"] = None


class CheckLinkResponse(BaseResponse):
    response: Optional["CheckLinkResponseModel"] = None


class CreateAdsResponse(BaseResponse):
    response: Optional["CreateAdsResponseModel"] = None


class CreateCampaignsResponse(BaseResponse):
    response: Optional["CreateCampaignsResponseModel"] = None


class CreateClientsResponse(BaseResponse):
    response: Optional["CreateClientsResponseModel"] = None


class CreateTargetGroupResponse(BaseResponse):
    response: Optional["CreateTargetGroupResponseModel"] = None


class DeleteAdsResponse(BaseResponse):
    response: Optional["DeleteAdsResponseModel"] = None


class DeleteCampaignsResponse(BaseResponse):
    response: Optional["DeleteCampaignsResponseModel"] = None


class DeleteClientsResponse(BaseResponse):
    response: Optional["DeleteClientsResponseModel"] = None


class GetAccountsResponse(BaseResponse):
    response: Optional["GetAccountsResponseModel"] = None


class GetAdsLayoutResponse(BaseResponse):
    response: Optional["GetAdsLayoutResponseModel"] = None


class GetAdsTargetingResponse(BaseResponse):
    response: Optional["GetAdsTargetingResponseModel"] = None


class GetAdsResponse(BaseResponse):
    response: Optional["GetAdsResponseModel"] = None


class GetBudgetResponse(BaseResponse):
    response: Optional["GetBudgetResponseModel"] = None


class GetCampaignsResponse(BaseResponse):
    response: Optional["GetCampaignsResponseModel"] = None


class GetCategoriesResponse(BaseResponse):
    response: Optional["GetCategoriesResponseModel"] = None


class GetClientsResponse(BaseResponse):
    response: Optional["GetClientsResponseModel"] = None


class GetDemographicsResponse(BaseResponse):
    response: Optional["GetDemographicsResponseModel"] = None


class GetFloodStatsResponse(BaseResponse):
    response: Optional["GetFloodStatsResponseModel"] = None


class GetLookalikeRequestsResponse(BaseResponse):
    response: Optional["GetLookalikeRequestsResponseModel"] = None


class GetMusiciansResponse(BaseResponse):
    response: Optional["GetMusiciansResponseModel"] = None


class GetOfficeUsersResponse(BaseResponse):
    response: Optional["GetOfficeUsersResponseModel"] = None


class GetPostsReachResponse(BaseResponse):
    response: Optional["GetPostsReachResponseModel"] = None


class GetRejectionReasonResponse(BaseResponse):
    response: Optional["GetRejectionReasonResponseModel"] = None


class GetStatisticsResponse(BaseResponse):
    response: Optional["GetStatisticsResponseModel"] = None


class GetSuggestionsCitiesResponse(BaseResponse):
    response: Optional["GetSuggestionsCitiesResponseModel"] = None


class GetSuggestionsRegionsResponse(BaseResponse):
    response: Optional["GetSuggestionsRegionsResponseModel"] = None


class GetSuggestionsResponse(BaseResponse):
    response: Optional["GetSuggestionsResponseModel"] = None


class GetSuggestionsSchoolsResponse(BaseResponse):
    response: Optional["GetSuggestionsSchoolsResponseModel"] = None


class GetTargetGroupsResponse(BaseResponse):
    response: Optional["GetTargetGroupsResponseModel"] = None


class GetTargetingStatsResponse(BaseResponse):
    response: Optional["GetTargetingStatsResponseModel"] = None


class GetUploadURLResponse(BaseResponse):
    response: Optional["GetUploadURLResponseModel"] = None


class GetVideoUploadURLResponse(BaseResponse):
    response: Optional["GetVideoUploadURLResponseModel"] = None


class ImportTargetContactsResponse(BaseResponse):
    response: Optional["ImportTargetContactsResponseModel"] = None


class RemoveOfficeUsersResponse(BaseResponse):
    response: Optional["RemoveOfficeUsersResponseModel"] = None


class UpdateAdsResponse(BaseResponse):
    response: Optional["UpdateAdsResponseModel"] = None


class UpdateCampaignsResponse(BaseResponse):
    response: Optional["UpdateCampaignsResponseModel"] = None


class UpdateClientsResponse(BaseResponse):
    response: Optional["UpdateClientsResponseModel"] = None


AddOfficeUsersResponseModel = bool

CheckLinkResponseModel = Optional[AdsLinkStatus]

CreateAdsResponseModel = List[int]

CreateCampaignsResponseModel = List[int]


CreateClientsResponseModel = List[int]


class CreateTargetGroupResponseModel(BaseResponse):
    id: Optional[int] = None
    pixel: Optional[str] = None


DeleteAdsResponseModel = List[int]


DeleteCampaignsResponseModel = int


DeleteClientsResponseModel = int

GetAccountsResponseModel = List[AdsAccount]

GetAdsLayoutResponseModel = List[AdsAdLayout]

GetAdsTargetingResponseModel = List[AdsTargSettings]

GetAdsResponseModel = List[AdsAd]


GetBudgetResponseModel = int

GetCampaignsResponseModel = List[AdsCampaign]


class GetCategoriesResponseModel(BaseResponse):
    v1: Optional[List["AdsCategory"]] = None
    v2: Optional[List["AdsCategory"]] = None


GetClientsResponseModel = List[AdsClient]

GetDemographicsResponseModel = List[AdsDemoStats]

GetFloodStatsResponseModel = Optional[AdsFloodStats]


class GetLookalikeRequestsResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["AdsLookalikeRequest"]] = None


class GetMusiciansResponseModel(BaseResponse):
    items: Optional[List["AdsMusician"]] = None


GetOfficeUsersResponseModel = List[AdsUsers]

GetPostsReachResponseModel = List[AdsPromotedPostReach]

GetRejectionReasonResponseModel = Optional[AdsRejectReason]

GetStatisticsResponseModel = List[AdsStats]

GetSuggestionsCitiesResponseModel = List[AdsTargSuggestionsCities]

GetSuggestionsRegionsResponseModel = List[AdsTargSuggestionsRegions]

GetSuggestionsResponseModel = List[AdsTargSuggestions]

GetSuggestionsSchoolsResponseModel = List[AdsTargSuggestionsSchools]

GetTargetGroupsResponseModel = List[AdsTargetGroup]

GetTargetingStatsResponseModel = Optional[AdsTargStats]


GetUploadURLResponseModel = str


GetVideoUploadURLResponseModel = str


ImportTargetContactsResponseModel = int


RemoveOfficeUsersResponseModel = bool


UpdateAdsResponseModel = List[int]


UpdateCampaignsResponseModel = int


UpdateClientsResponseModel = int

AddOfficeUsersResponse.update_forward_refs()
CheckLinkResponse.update_forward_refs()
CreateAdsResponse.update_forward_refs()
CreateCampaignsResponse.update_forward_refs()
CreateClientsResponse.update_forward_refs()
CreateTargetGroupResponse.update_forward_refs()
DeleteAdsResponse.update_forward_refs()
DeleteCampaignsResponse.update_forward_refs()
DeleteClientsResponse.update_forward_refs()
GetAccountsResponse.update_forward_refs()
GetAdsLayoutResponse.update_forward_refs()
GetAdsTargetingResponse.update_forward_refs()
GetAdsResponse.update_forward_refs()
GetBudgetResponse.update_forward_refs()
GetCampaignsResponse.update_forward_refs()
GetCategoriesResponse.update_forward_refs()
GetClientsResponse.update_forward_refs()
GetDemographicsResponse.update_forward_refs()
GetFloodStatsResponse.update_forward_refs()
GetLookalikeRequestsResponse.update_forward_refs()
GetMusiciansResponse.update_forward_refs()
GetOfficeUsersResponse.update_forward_refs()
GetPostsReachResponse.update_forward_refs()
GetRejectionReasonResponse.update_forward_refs()
GetStatisticsResponse.update_forward_refs()
GetSuggestionsCitiesResponse.update_forward_refs()
GetSuggestionsRegionsResponse.update_forward_refs()
GetSuggestionsResponse.update_forward_refs()
GetSuggestionsSchoolsResponse.update_forward_refs()
GetTargetGroupsResponse.update_forward_refs()
GetTargetingStatsResponse.update_forward_refs()
GetUploadURLResponse.update_forward_refs()
GetVideoUploadURLResponse.update_forward_refs()
ImportTargetContactsResponse.update_forward_refs()
RemoveOfficeUsersResponse.update_forward_refs()
UpdateAdsResponse.update_forward_refs()
UpdateCampaignsResponse.update_forward_refs()
UpdateClientsResponse.update_forward_refs()



import typing
from typing import Optional, List

from vkbottle_types.responses import newsfeed, base
from .base_category import BaseCategory

if typing.TYPE_CHECKING:
    from vkbottle_types.objects import (
        users as objects_users,
        newsfeed as objects_newsfeed,
        base as objects_base,
    )


class NewsfeedCategory(BaseCategory):
    async def add_ban(
        self,
        user_ids: Optional[List[int]] = None,
        group_ids: Optional[List[int]] = None,
        **kwargs
    ) -> base.OkResponseModel:
        """Prevents news from specified users and communities from appearing in the current user's newsfeed.
        :param user_ids:
        :param group_ids:
        """

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("newsfeed.addBan", params))

    async def delete_ban(
        self,
        user_ids: Optional[List[int]] = None,
        group_ids: Optional[List[int]] = None,
        **kwargs
    ) -> base.OkResponseModel:
        """Allows news from previously banned users and communities to be shown in the current user's newsfeed.
        :param user_ids:
        :param group_ids:
        """

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("newsfeed.deleteBan", params))

    async def delete_list(self, list_id: int, **kwargs) -> base.OkResponseModel:
        """newsfeed.deleteList method
        :param list_id:
        """

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("newsfeed.deleteList", params))

    async def get(
        self,
        filters: Optional[List["objects_newsfeed.Filters"]] = None,
        return_banned: Optional[bool] = None,
        start_time: Optional[int] = None,
        end_time: Optional[int] = None,
        max_photos: Optional[int] = None,
        source_ids: Optional[str] = None,
        start_from: Optional[str] = None,
        count: Optional[int] = None,
        fields: Optional[List["objects_base.UserGroupFields"]] = None,
        section: Optional[str] = None,
        **kwargs
    ) -> newsfeed.GetResponseModel:
        """Returns data required to show newsfeed for the current user.
        :param filters: Filters to apply: 'post' — new wall posts, 'photo' — new photos, 'photo_tag' — new photo tags, 'wall_photo' — new wall photos, 'friend' — new friends, 'note' — new notes
        :param return_banned: '1' — to return news items from banned sources
        :param start_time: Earliest timestamp (in Unix time, **kwargs) of a news item to return. By default, 24 hours ago.
        :param end_time: Latest timestamp (in Unix time, **kwargs) of a news item to return. By default, the current time.
        :param max_photos: Maximum number of photos to return. By default, '5'.
        :param source_ids: Sources to obtain news from, separated by commas. User IDs can be specified in formats '' or 'u' , where '' is the user's friend ID. Community IDs can be specified in formats '-' or 'g' , where '' is the community ID. If the parameter is not set, all of the user's friends and communities are returned, except for banned sources, which can be obtained with the [vk.com/dev/newsfeed.getBanned|newsfeed.getBanned] method.
        :param start_from: identifier required to get the next page of results. Value for this parameter is returned in 'next_from' field in a reply.
        :param count: Number of news items to return (default 50, maximum 100). For auto feed, you can use the 'new_offset' parameter returned by this method.
        :param fields: Additional fields of [vk.com/dev/fields|profiles] and [vk.com/dev/fields_groups|communities] to return.
        :param section:
        """

        params = self.get_set_params(locals())
        return newsfeed.GetResponse(**await self.api.request("newsfeed.get", params))

    async def get_banned(
        self,
        extended: Optional[bool] = None,
        fields: Optional[List["objects_users.Fields"]] = None,
        name_case: Optional[str] = None,
        **kwargs
    ) -> newsfeed.GetBannedExtendedResponseModel:
        """Returns a list of users and communities banned from the current user's newsfeed.
        :param extended: '1' — return extra information about users and communities
        :param fields: Profile fields to return.
        :param name_case: Case for declension of user name and surname: 'nom' — nominative (default), 'gen' — genitive , 'dat' — dative, 'acc' — accusative , 'ins' — instrumental , 'abl' — prepositional
        """

        params = self.get_set_params(locals())
        return newsfeed.GetBannedExtendedResponse(
            **await self.api.request("newsfeed.getBanned", params)
        )

    async def get_comments(
        self,
        count: Optional[int] = None,
        filters: Optional[List["objects_newsfeed.CommentsFilters"]] = None,
        reposts: Optional[str] = None,
        start_time: Optional[int] = None,
        end_time: Optional[int] = None,
        last_comments_count: Optional[int] = None,
        start_from: Optional[str] = None,
        fields: Optional[List["objects_base.UserGroupFields"]] = None,
        **kwargs
    ) -> newsfeed.GetCommentsResponseModel:
        """Returns a list of comments in the current user's newsfeed.
        :param count: Number of comments to return. For auto feed, you can use the 'new_offset' parameter returned by this method.
        :param filters: Filters to apply: 'post' — new comments on wall posts, 'photo' — new comments on photos, 'video' — new comments on videos, 'topic' — new comments on discussions, 'note' — new comments on notes,
        :param reposts: Object ID, comments on repost of which shall be returned, e.g. 'wall1_45486'. (If the parameter is set, the 'filters' parameter is optional.),
        :param start_time: Earliest timestamp (in Unix time, **kwargs) of a comment to return. By default, 24 hours ago.
        :param end_time: Latest timestamp (in Unix time, **kwargs) of a comment to return. By default, the current time.
        :param last_comments_count:
        :param start_from: Identificator needed to return the next page with results. Value for this parameter returns in 'next_from' field.
        :param fields: Additional fields of [vk.com/dev/fields|profiles] and [vk.com/dev/fields_groups|communities] to return.
        """

        params = self.get_set_params(locals())
        return newsfeed.GetCommentsResponse(
            **await self.api.request("newsfeed.getComments", params)
        )

    async def get_lists(
        self,
        list_ids: Optional[List[int]] = None,
        extended: Optional[bool] = None,
        **kwargs
    ) -> newsfeed.GetListsExtendedResponseModel:
        """Returns a list of newsfeeds followed by the current user.
        :param list_ids: numeric list identifiers.
        :param extended: Return additional list info
        """

        params = self.get_set_params(locals())
        return newsfeed.GetListsExtendedResponse(
            **await self.api.request("newsfeed.getLists", params)
        )

    async def get_mentions(
        self,
        owner_id: Optional[int] = None,
        start_time: Optional[int] = None,
        end_time: Optional[int] = None,
        offset: Optional[int] = None,
        count: Optional[int] = None,
        **kwargs
    ) -> newsfeed.GetMentionsResponseModel:
        """Returns a list of posts on user walls in which the current user is mentioned.
        :param owner_id: Owner ID.
        :param start_time: Earliest timestamp (in Unix time, **kwargs) of a post to return. By default, 24 hours ago.
        :param end_time: Latest timestamp (in Unix time, **kwargs) of a post to return. By default, the current time.
        :param offset: Offset needed to return a specific subset of posts.
        :param count: Number of posts to return.
        """

        params = self.get_set_params(locals())
        return newsfeed.GetMentionsResponse(
            **await self.api.request("newsfeed.getMentions", params)
        )

    async def get_recommended(
        self,
        start_time: Optional[int] = None,
        end_time: Optional[int] = None,
        max_photos: Optional[int] = None,
        start_from: Optional[str] = None,
        count: Optional[int] = None,
        fields: Optional[List["objects_base.UserGroupFields"]] = None,
        **kwargs
    ) -> newsfeed.GetRecommendedResponseModel:
        """, Returns a list of newsfeeds recommended to the current user.
        :param start_time: Earliest timestamp (in Unix time, **kwargs) of a news item to return. By default, 24 hours ago.
        :param end_time: Latest timestamp (in Unix time, **kwargs) of a news item to return. By default, the current time.
        :param max_photos: Maximum number of photos to return. By default, '5'.
        :param start_from: 'new_from' value obtained in previous call.
        :param count: Number of news items to return.
        :param fields: Additional fields of [vk.com/dev/fields|profiles] and [vk.com/dev/fields_groups|communities] to return.
        """

        params = self.get_set_params(locals())
        return newsfeed.GetRecommendedResponse(
            **await self.api.request("newsfeed.getRecommended", params)
        )

    async def get_suggested_sources(
        self,
        offset: Optional[int] = None,
        count: Optional[int] = None,
        shuffle: Optional[bool] = None,
        fields: Optional[List["objects_base.UserGroupFields"]] = None,
        **kwargs
    ) -> newsfeed.GetSuggestedSourcesResponseModel:
        """Returns communities and users that current user is suggested to follow.
        :param offset: offset required to choose a particular subset of communities or users.
        :param count: amount of communities or users to return.
        :param shuffle: shuffle the returned list or not.
        :param fields: list of extra fields to be returned. See available fields for [vk.com/dev/fields|users] and [vk.com/dev/fields_groups|communities].
        """

        params = self.get_set_params(locals())
        return newsfeed.GetSuggestedSourcesResponse(
            **await self.api.request("newsfeed.getSuggestedSources", params)
        )

    async def ignore_item(
        self, type: str, owner_id: int, item_id: int, **kwargs
    ) -> base.OkResponseModel:
        """Hides an item from the newsfeed.
        :param type: Item type. Possible values: *'wall' – post on the wall,, *'tag' – tag on a photo,, *'profilephoto' – profile photo,, *'video' – video,, *'audio' – audio.
        :param owner_id: Item owner's identifier (user or community), "Note that community id must be negative. 'owner_id=1' – user , 'owner_id=-1' – community "
        :param item_id: Item identifier
        """

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("newsfeed.ignoreItem", params))

    async def save_list(
        self,
        title: str,
        list_id: Optional[int] = None,
        source_ids: Optional[List[int]] = None,
        no_reposts: Optional[bool] = None,
        **kwargs
    ) -> newsfeed.SaveListResponseModel:
        """Creates and edits user newsfeed lists
        :param title: list name.
        :param list_id: numeric list identifier (if not sent, will be set automatically).
        :param source_ids: users and communities identifiers to be added to the list. Community identifiers must be negative numbers.
        :param no_reposts: reposts display on and off ('1' is for off).
        """

        params = self.get_set_params(locals())
        return newsfeed.SaveListResponse(
            **await self.api.request("newsfeed.saveList", params)
        )

    async def search(
        self,
        q: Optional[str] = None,
        extended: Optional[bool] = None,
        count: Optional[int] = None,
        latitude: Optional[float] = None,
        longitude: Optional[float] = None,
        start_time: Optional[int] = None,
        end_time: Optional[int] = None,
        start_from: Optional[str] = None,
        fields: Optional[List["objects_base.UserGroupFields"]] = None,
        **kwargs
    ) -> newsfeed.SearchExtendedResponseModel:
        """Returns search results by statuses.
        :param q: Search query string (e.g., 'New Year').
        :param extended: '1' — to return additional information about the user or community that placed the post.
        :param count: Number of posts to return.
        :param latitude: Geographical latitude point (in degrees, -90 to 90, **kwargs) within which to search.
        :param longitude: Geographical longitude point (in degrees, -180 to 180, **kwargs) within which to search.
        :param start_time: Earliest timestamp (in Unix time, **kwargs) of a news item to return. By default, 24 hours ago.
        :param end_time: Latest timestamp (in Unix time, **kwargs) of a news item to return. By default, the current time.
        :param start_from:
        :param fields: Additional fields of [vk.com/dev/fields|profiles] and [vk.com/dev/fields_groups|communities] to return.
        """

        params = self.get_set_params(locals())
        return newsfeed.SearchExtendedResponse(
            **await self.api.request("newsfeed.search", params)
        )

    async def unignore_item(
        self,
        type: str,
        owner_id: int,
        item_id: int,
        track_code: Optional[str] = None,
        **kwargs
    ) -> base.OkResponseModel:
        """Returns a hidden item to the newsfeed.
        :param type: Item type. Possible values: *'wall' – post on the wall,, *'tag' – tag on a photo,, *'profilephoto' – profile photo,, *'video' – video,, *'audio' – audio.
        :param owner_id: Item owner's identifier (user or community), "Note that community id must be negative. 'owner_id=1' – user , 'owner_id=-1' – community "
        :param item_id: Item identifier
        :param track_code: Track code of unignored item
        """

        params = self.get_set_params(locals())
        return base.OkResponse(
            **await self.api.request("newsfeed.unignoreItem", params)
        )

    async def unsubscribe(
        self, type: str, item_id: int, owner_id: Optional[int] = None, **kwargs
    ) -> base.OkResponseModel:
        """Unsubscribes the current user from specified newsfeeds.
        :param type: Type of object from which to unsubscribe: 'note' — note, 'photo' — photo, 'post' — post on user wall or community wall, 'topic' — topic, 'video' — video
        :param item_id: Object ID.
        :param owner_id: Object owner ID.
        """

        params = self.get_set_params(locals())
        return base.OkResponse(**await self.api.request("newsfeed.unsubscribe", params))
